var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import React, { Fragment, useContext, useEffect, useState, } from 'react';
import AuthContext from './AuthContext';
import OrdersContext from './OrdersContext';
import ConfigContext from './ConfigContext';
import * as orderingCore from '@orderingstack/ordering-core';
export default function OrderProvider(props) {
    const _configContext = useContext(ConfigContext);
    if (!_configContext) {
        return React.createElement(Fragment, null, "Configuration should be provided");
    }
    const config = _configContext;
    const [orders, setOrders] = useState({ orderRecMap: {}, loaded: false });
    const { authProvider, loggedIn } = useContext(AuthContext);
    const onOrdersUpdated = (order, allOrders) => {
        //console.log("--------------" + Object.keys(allOrders).length);
        setOrders({
            orderRecMap: Object.assign({}, allOrders),
            loaded: true,
            error: undefined,
        });
    };
    function setOrderChangesListener(authProvider) {
        return __awaiter(this, void 0, void 0, function* () {
            let disconnect = () => {
                return Promise.resolve();
            };
            try {
                const { token } = yield authProvider();
                if (token) {
                    disconnect = yield orderingCore.orderChangesListener(config.baseUrl, config.tenant, config.venue, authProvider, onOrdersUpdated, () => {
                        setOrders({
                            orderRecMap: {},
                            loaded: false,
                            error: new Error('auth failure'),
                        });
                        return Promise.resolve();
                    }, config.enableKDS, props.onWebsocketNotification, props.onSteeringCommand, {
                        appInsights: props.appInsights,
                        debugWs: props.debugWs,
                        onlyCompletedOrdersForUser: props.onlyCompletedOrdersForUser,
                    });
                }
            }
            catch (err) {
                setOrders({ orderRecMap: {}, loaded: false, error: err });
            }
            return disconnect;
        });
    }
    useEffect(() => {
        orderingCore.setOrderStoreUpdatedCallback(onOrdersUpdated);
        const promise = setOrderChangesListener(authProvider);
        return () => {
            promise.then((disconnect) => disconnect());
        };
    }, [loggedIn]);
    return (React.createElement(Fragment, null,
        React.createElement(OrdersContext.Provider, { value: orders }, props.children)));
}
